@@ -3,7 +3,7 @@ This module tests the `/deposit` endpoint.
 Celery tasks are called synchronously. Horizon calls are mocked for speed and correctness.
 """
 import json
-from unittest.mock import patch, Mock
+from unittest.mock import patch
 import jwt
 import time
 
@@ -13,6 +13,7 @@ from stellar_sdk import Keypair
 
 from polaris import settings
 from polaris.models import Transaction, Asset
+from polaris.integrations import TransactionForm
 from polaris.tests.helpers import (
     mock_check_auth_success,
     mock_check_auth_success_client_domain,
@@ -591,6 +592,70 @@ def test_interactive_deposit_post_no_content_tx_complete(
     )
 
 
+@pytest.mark.django_db
+@patch("polaris.sep24.deposit.rdi.content_for_template")
+def test_interactive_deposit_post_validation_is_called_before_next_form(
+    mock_content_for_template, client
+):
+    """
+    Ensures we call DepositIntegration.after_form_validation() for the posted form data
+    before we call DepositIntegration.form_for_transaction() to retrieve the next form
+    """
+    usd = Asset.objects.create(
+        code="USD",
+        issuer=Keypair.random().public_key,
+        sep24_enabled=True,
+        deposit_enabled=True,
+    )
+    deposit = Transaction.objects.create(
+        asset=usd, kind=Transaction.KIND.deposit, status=Transaction.STATUS.incomplete
+    )
+
+    mock_content_for_template.return_value = {"test": "value"}
+    payload = interactive_jwt_payload(deposit, "deposit")
+    token = jwt.encode(payload, settings.SERVER_JWT_KEY, algorithm="HS256")
+    returned_bound_form = False
+    validated = False
+
+    def mock_after_form_validation(*args, **kwargs):
+        nonlocal validated
+        validated = True
+
+    def mock_form_for_transaction(*args, **kwargs):
+        nonlocal returned_bound_form
+        if kwargs.get("post_data"):
+            returned_bound_form = True
+            return TransactionForm(kwargs.get("transaction"), kwargs.get("post_data"))
+        else:
+            if returned_bound_form and not validated:
+                raise RuntimeError()
+            return TransactionForm(kwargs.get("transaction"))
+
+    with patch(
+        "polaris.sep24.deposit.rdi.form_for_transaction", mock_form_for_transaction
+    ):
+        with patch(
+            "polaris.sep24.deposit.rdi.after_form_validation",
+            mock_after_form_validation,
+        ):
+            response = client.get(
+                f"{WEBAPP_PATH}"
+                f"?token={token}"
+                f"&transaction_id={deposit.id}"
+                f"&asset_code={usd.code}"
+            )
+            assert response.status_code == 200
+            assert client.session["authenticated"] is True
+
+            response = client.post(
+                f"{WEBAPP_PATH}/submit"
+                f"?transaction_id={deposit.id}"
+                f"&asset_code={deposit.asset.code}",
+                {"amount": 100},
+            )
+            assert response.status_code == 302
+
+
 @pytest.mark.django_db()
 @patch("polaris.sep24.deposit.rdi.interactive_url")
 def test_deposit_interactive_complete(mock_interactive_url, client):
